summaryrefslogtreecommitdiff
path: root/include/test_util.h
diff options
context:
space:
mode:
authorDossym Nurmukhanov <dossym@google.com>2020-12-12 04:41:45 +0000
committerCommit Bot <commit-bot@chromium.org>2020-12-12 20:39:35 +0000
commit8223f2d538f3d40b1a306661312201118a00dbd5 (patch)
treeb281082f44ca52ed8f596e9b67aa7fc8a6f810a1 /include/test_util.h
parent52863374ad592b80b24def9689856ecda2d645d0 (diff)
downloadchrome-ec-8223f2d538f3d40b1a306661312201118a00dbd5.tar.gz
COIL: Clean up controller/peripheral language in headers
BUG=none TEST=verify builds are still working BRANCH=none Signed-off-by: dossym@chromium.org Change-Id: I8925a7ffd3ab4e47dfed213438f601d673188259 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2588008 Reviewed-by: Daisuke Nojiri <dnojiri@chromium.org>
Diffstat (limited to 'include/test_util.h')
-rw-r--r--include/test_util.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/test_util.h b/include/test_util.h
index 10cc415401..d33691a626 100644
--- a/include/test_util.h
+++ b/include/test_util.h
@@ -289,7 +289,7 @@ struct test_i2c_write_dev {
*
* When this function is called, it should either perform the desired
* mock functionality, or return EC_ERROR_INVAL to indicate it does
- * not respond to the specified port and slave address.
+ * not respond to the specified port and peripheral address.
*
* @param routine Function pointer, with the same prototype as i2c_xfer()
*/
@@ -301,24 +301,24 @@ struct test_i2c_write_dev {
/*
* Detach an I2C device. Once detached, any read/write command regarding the
- * specified port and slave address returns error.
+ * specified port and peripheral address returns error.
*
* @param port The port that the detached device is connected to
* @param slave_addr The address of the detached device
* @return EC_SUCCESS if detached; EC_ERROR_OVERFLOW if too many devices are
* detached.
*/
-int test_detach_i2c(const int port, const uint16_t slave_addr_flags);
+int test_detach_i2c(const int port, const uint16_t addr_flags);
/*
* Re-attach an I2C device.
*
* @param port The port that the detached device is connected to
* @param slave_addr The address of the detached device
* @return EC_SUCCESS if re-attached; EC_ERROR_INVAL if the specified device
* is not a detached device.
*/
-int test_attach_i2c(const int port, const uint16_t slave_addr_flags);
+int test_attach_i2c(const int port, const uint16_t addr_flags);
/*
* We need these macros so that a test can be built for either Ztest or the
@@ -301,24 +301,24 @@ struct test_i2c_write_dev {
*
* @param port The port that the detached device is connected to
- * @param slave_addr The address of the detached device
+ * @param addr_flags The address of the detached device
* @return EC_SUCCESS if detached; EC_ERROR_OVERFLOW if too many devices are
* detached.
@@ -301,24 +301,24 @@ struct test_i2c_write_dev {
*
* @param port The port that the detached device is connected to
- * @param slave_addr The address of the detached device
+ * @param addr_flags The address of the detached device
* @return EC_SUCCESS if re-attached; EC_ERROR_INVAL if the specified device
* is not a detached device.